@@ -267,7 +267,7 @@ netstatus_sysdeps_read_iface_statistics (const char *iface,
   *out_bytes   = -1;
 
   error = NULL;
-  command_line = g_strdup_printf ("/usr/bin/netstat netstat -n -I %s -b -f inet", iface);
+  command_line = g_strdup_printf ("/usr/bin/netstat -n -I %s -b -f inet", iface);
   if (!g_shell_parse_argv (command_line, NULL, &argv, &error))
     {
       error_message = g_strdup_printf (_("Could not parse command line '%s': %s"),
